@@ -22,7 +22,7 @@
 #include <libgnome/gnome-i18n.h>
 #include "gnome-db-control-widget.h"
 #include "gnome-db-config.h"
-#include "GnomeDB.h"
+#include "GNOME_Database_UI.h"
 
 static void gnome_db_control_widget_class_init (GnomeDbControlWidgetClass *klass);
 static void gnome_db_control_widget_init       (GnomeDbControlWidget *widget);
@@ -92,6 +92,18 @@ gnome_db_control_widget_get_type (void)
 
 /**
  * gnome_db_control_widget_new
+ * @id: ID of the Bonobo control to be loaded
+ * @uic: a reference to the Bonobo_UIContainer to use for the control
+ *
+ * Creates a new widget that loads the Bonobo control specified by the
+ * @id parameter.
+ * The second argument, @uic, is needed to associate a Bonobo container
+ * with the new control, so that menus and toolbars are merged. This is
+ * easily done by using a #GnomeDbWindow for all your Bonobo container needs,
+ * and then use the #gnome_db_window_get_ui_container to retrieve the
+ * Bonobo_UIContainer associated with the #GnomeDbWindow widget.
+ *
+ * Returns: a pointer to the newly-created widget
  */
 GtkWidget *
 gnome_db_control_widget_new (const gchar *id, Bonobo_UIContainer uic)
@@ -183,6 +195,12 @@ gnome_db_control_widget_supported (const gchar *goad_id)
 
 /**
  * gnome_db_control_widget_is_alive
+ * @wid: a #GnomeDbControlWidget widget
+ *
+ * Pings the given #GnomeDbControlWidget widget to see if the underlying
+ * CORBA server is still alive.
+ *
+ * Returns: TRUE if alive, FALSE if dead
  */
 gboolean
 gnome_db_control_widget_is_alive (GnomeDbControlWidget *wid)
@@ -206,6 +224,12 @@ gnome_db_control_widget_is_alive (GnomeDbControlWidget *wid)
 
 /**
  * gnome_db_control_widget_activate
+ * @wid: a #GnomeDbControlWidget widget
+ *
+ * Activates the given #GnomeDbControlWidget widget. This means that the
+ * underlying control's menus and toolbars will be merged with the menus
+ * and toolbars of the container being used, generally a #GnomeDbWindow
+ * widget.
  */
 void
 gnome_db_control_widget_activate (GnomeDbControlWidget *wid)
@@ -221,6 +245,10 @@ gnome_db_control_widget_activate (GnomeDbControlWidget *wid)
 
 /**
  * gnome_db_control_widget_deactivate
+ * @wid: a #GnomeDbControlWidget widget
+ *
+ * Deactivates the given #GnomeDbControlWidget widget. This means that all
+ * of the control's menus and toolbars are removed from the container.
  */
 void
 gnome_db_control_widget_deactivate (GnomeDbControlWidget *wid)
@@ -237,6 +265,10 @@ gnome_db_control_widget_deactivate (GnomeDbControlWidget *wid)
 /* 
  * Functions to manipulate controls from the properties.
  */
+
+/**
+ * gnome_db_control_widget_prop_supported
+ */
 gboolean 
 gnome_db_control_widget_prop_supported (GnomeDbControlWidget *wid, 
                                         const gchar *prop_name)
@@ -367,13 +399,13 @@ gnome_db_control_widget_get_gnomedb_control (GnomeDbControlWidget *wid)
 		BonoboObjectClient* client;
 
 		client = bonobo_widget_get_server (BONOBO_WIDGET (wid->bonobo_widget));
-		wid->gnomedb_control = (GNOME_DB_Control)
+		wid->gnomedb_control = (GNOME_Database_UIControl)
 			Bonobo_Unknown_queryInterface (
 				bonobo_object_corba_objref (BONOBO_OBJECT (client)),
-				 GNOME_DB_REPO_CONTROL,
+				GNOME_DB_REPO_CONTROL,
 				&ev);
 		if (wid->gnomedb_control == CORBA_OBJECT_NIL) {
-			g_warning (_("Could not get GNOME_DB_Control interface"));
+			g_warning (_("Could not get GNOME_Database_UIControl interface"));
 		}
 	}
 	CORBA_exception_free (&ev);
@@ -385,11 +417,13 @@ gnome_db_control_widget_get_gnomedb_control (GnomeDbControlWidget *wid)
  * @wid: control widget
  *
  * Return the version supported by the underlying control.
+ *
+ * Returns: a newly allocated string that contains the version number.
  */
 gchar *
 gnome_db_control_widget_get_version (GnomeDbControlWidget *wid)
 {
-	GNOME_DB_Control gnomedb_control;
+	GNOME_Database_UIControl gnomedb_control;
 	
 	g_return_val_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid), NULL);
 	g_return_val_if_fail(BONOBO_IS_WIDGET(wid->bonobo_widget), NULL);
@@ -401,7 +435,7 @@ gnome_db_control_widget_get_version (GnomeDbControlWidget *wid)
 		gchar*            version = NULL;
 		
 		CORBA_exception_init(&ev);
-		retval = GNOME_DB_Control_getVersion(gnomedb_control, &ev);
+		retval = GNOME_Database_UIControl_getVersion(gnomedb_control, &ev);
 		if (ev._major == CORBA_NO_EXCEPTION) version = g_strdup(retval);
 		CORBA_exception_free(&ev);
 		return version;
@@ -415,7 +449,7 @@ gnome_db_control_widget_get_version (GnomeDbControlWidget *wid)
 gchar *
 gnome_db_control_instance_get_authors (GnomeDbControlWidget *wid)
 {
-	GNOME_DB_Control gnomedb_control;
+	GNOME_Database_UIControl gnomedb_control;
 	
 	g_return_val_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid), NULL);
 	g_return_val_if_fail(BONOBO_IS_WIDGET(wid->bonobo_widget), NULL);
@@ -427,7 +461,7 @@ gnome_db_control_instance_get_authors (GnomeDbControlWidget *wid)
 		gchar*            version = NULL;
 		
 		CORBA_exception_init(&ev);
-		retval = GNOME_DB_Control_getAuthors(gnomedb_control, &ev);
+		retval = GNOME_Database_UIControl_getAuthors(gnomedb_control, &ev);
 		if (ev._major == CORBA_NO_EXCEPTION) version = g_strdup(retval);
 		CORBA_exception_free(&ev);
 		return version;
@@ -442,7 +476,7 @@ gnome_db_control_instance_get_authors (GnomeDbControlWidget *wid)
 void
 gnome_db_control_widget_run (GnomeDbControlWidget *wid)
 {
-	GNOME_DB_Control gnomedb_control;
+	GNOME_Database_UIControl gnomedb_control;
 	
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
 	g_return_if_fail(BONOBO_IS_WIDGET(wid->bonobo_widget));
@@ -452,18 +486,19 @@ gnome_db_control_widget_run (GnomeDbControlWidget *wid)
 		CORBA_Environment ev;
 		
 		CORBA_exception_init(&ev);
-		GNOME_DB_Control_run(gnomedb_control, &ev);
+		GNOME_Database_UIControl_run(gnomedb_control, &ev);
 		CORBA_exception_free(&ev);
 	}
 }
 
 /**
  * gnome_db_control_widget_set_owner
+ * @wid: a #GnomeDbControlWidget widget
  */
 void
 gnome_db_control_widget_set_owner (GnomeDbControlWidget *wid)
 {
-	GNOME_DB_Control gnomedb_control;
+	GNOME_Database_UIControl gnomedb_control;
 
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
 	g_return_if_fail(BONOBO_IS_WIDGET(wid->bonobo_widget));
@@ -473,7 +508,7 @@ gnome_db_control_widget_set_owner (GnomeDbControlWidget *wid)
 		CORBA_Environment ev;
 		
 		CORBA_exception_init(&ev);
-		GNOME_DB_Control_setOwner(gnomedb_control, &ev);
+		GNOME_Database_UIControl_setOwner(gnomedb_control, &ev);
 		CORBA_exception_free(&ev);
 	}
 }
@@ -484,7 +519,7 @@ gnome_db_control_widget_set_owner (GnomeDbControlWidget *wid)
 void
 gnome_db_control_widget_unset_owner (GnomeDbControlWidget *wid)
 {
-	GNOME_DB_Control gnomedb_control;
+	GNOME_Database_UIControl gnomedb_control;
 
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
 	g_return_if_fail(BONOBO_IS_WIDGET(wid->bonobo_widget));
@@ -494,7 +529,7 @@ gnome_db_control_widget_unset_owner (GnomeDbControlWidget *wid)
 		CORBA_Environment ev;
 		
 		CORBA_exception_init(&ev);
-		GNOME_DB_Control_unsetOwner(gnomedb_control, &ev);
+		GNOME_Database_UIControl_unsetOwner(gnomedb_control, &ev);
 		CORBA_exception_free(&ev);
 	}
 }
@@ -506,7 +541,7 @@ gnome_db_control_widget_unset_owner (GnomeDbControlWidget *wid)
 void
 gnome_db_control_widget_do_print (GnomeDbControlWidget *wid)
 {
-	GNOME_DB_Control gnomedb_control;
+	GNOME_Database_UIControl gnomedb_control;
 	
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
 	g_return_if_fail(BONOBO_IS_WIDGET(wid->bonobo_widget));
@@ -516,7 +551,7 @@ gnome_db_control_widget_do_print (GnomeDbControlWidget *wid)
 		CORBA_Environment ev;
 		
 		CORBA_exception_init(&ev);
-		GNOME_DB_Control_doPrint(gnomedb_control, &ev);
+		GNOME_Database_UIControl_doPrint(gnomedb_control, &ev);
 		CORBA_exception_free(&ev);
 	}
 }
@@ -528,7 +563,7 @@ gnome_db_control_widget_do_print (GnomeDbControlWidget *wid)
 void
 gnome_db_control_widget_do_cut_clipboard (GnomeDbControlWidget *wid)
 {
-	GNOME_DB_Control gnomedb_control;
+	GNOME_Database_UIControl gnomedb_control;
 	
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
 	g_return_if_fail(BONOBO_IS_WIDGET(wid->bonobo_widget));
@@ -538,7 +573,7 @@ gnome_db_control_widget_do_cut_clipboard (GnomeDbControlWidget *wid)
 		CORBA_Environment ev;
 		
 		CORBA_exception_init(&ev);
-		GNOME_DB_Control_doCutClipboard(gnomedb_control, &ev);
+		GNOME_Database_UIControl_doCutClipboard(gnomedb_control, &ev);
 		CORBA_exception_free(&ev);
 	}
 }
@@ -550,7 +585,7 @@ gnome_db_control_widget_do_cut_clipboard (GnomeDbControlWidget *wid)
 void
 gnome_db_control_widget_do_copy_clipboard (GnomeDbControlWidget *wid)
 {
-	GNOME_DB_Control gnomedb_control;
+	GNOME_Database_UIControl gnomedb_control;
 	
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
 	g_return_if_fail(BONOBO_IS_WIDGET(wid->bonobo_widget));
@@ -560,7 +595,7 @@ gnome_db_control_widget_do_copy_clipboard (GnomeDbControlWidget *wid)
 		CORBA_Environment ev;
 		
 		CORBA_exception_init(&ev);
-		GNOME_DB_Control_doCopyClipboard(gnomedb_control, &ev);
+		GNOME_Database_UIControl_doCopyClipboard(gnomedb_control, &ev);
 		CORBA_exception_free(&ev);
 	}
 }
@@ -572,7 +607,7 @@ gnome_db_control_widget_do_copy_clipboard (GnomeDbControlWidget *wid)
 void
 gnome_db_control_widget_do_paste_clipboard (GnomeDbControlWidget *wid)
 {
-	GNOME_DB_Control gnomedb_control;
+	GNOME_Database_UIControl gnomedb_control;
 	
 	g_return_if_fail(GNOME_DB_IS_CONTROL_WIDGET(wid));
 	g_return_if_fail(BONOBO_IS_WIDGET(wid->bonobo_widget));
@@ -582,7 +617,7 @@ gnome_db_control_widget_do_paste_clipboard (GnomeDbControlWidget *wid)
 		CORBA_Environment ev;
 		
 		CORBA_exception_init(&ev);
-		GNOME_DB_Control_doPasteClipboard(gnomedb_control, &ev);
+		GNOME_Database_UIControl_doPasteClipboard(gnomedb_control, &ev);
 		CORBA_exception_free(&ev);
 	}
 }
