@@ -20,8 +20,8 @@
 #if !defined(__gnome_db_moniker_h__)
 #  define __gnome_db_moniker_h__
 
-#include <gnome.h>
-#include <bonobo/bonobo-moniker.h>
+#include <libgnome/gnome-defs.h>
+#include <bonobo/bonobo-moniker-simple.h>
 
 BEGIN_GNOME_DECLS
 
@@ -40,20 +40,21 @@ typedef Bonobo_Unknown (*GnomeDbMonikerResolveFunc)(GnomeDbMoniker *moniker,
                                                     const gchar *requested_interface);
 
 struct _GnomeDbMoniker {
-	BonoboMoniker          moniker;
+	BonoboMonikerSimple    moniker;
 	GnomeDbMonikerPrivate* priv;
 };
 
 struct _GnomeDbMonikerClass {
-	BonoboMonikerClass parent_class;
+	BonoboMonikerSimpleClass parent_class;
 };
 
-GtkType         gnome_db_moniker_get_type   (void);
+GtkType         gnome_db_moniker_get_type (void);
 
-GnomeDbMoniker* gnome_db_moniker_new        (const gchar *oafiid,
-                                             const gchar *prefix,
-                                             GnomeDbMonikerResolveFunc resolve_func);
-const gchar*    gnome_db_moniker_get_oafiid (GnomeDbMoniker *moniker);
+GnomeDbMoniker* gnome_db_moniker_new (const gchar *prefix,
+                                      GnomeDbMonikerResolveFunc resolve_func);
+GnomeDbMoniker* gnome_db_moniker_construct (GnomeDbMoniker *moniker,
+                                            const gchar *prefix,
+                                            GnomeDbMonikerResolveFunc resolve_func);
 
 #define gnome_db_moniker_get_name(_moniker_) bonobo_moniker_get_name(BONOBO_MONIKER((_moniker_)))
 
