@@ -18,10 +18,11 @@
  */
  
 #include "gnome-db-report.h"
+#include <gtk/gtksignal.h>
 
 static void gnome_db_report_class_init (GnomeDbReportClass *);
-static void gnome_db_report_init       (GnomeDbReport *);
-static void gnome_db_report_destroy    (GnomeDbReport *);
+static void gnome_db_report_init (GnomeDbReport *);
+static void gnome_db_report_destroy (GtkObject *object);
 
 /*
  * GnomeDbReport widget signals
@@ -39,12 +40,15 @@ static gint gnome_db_report_signals[GNOME_DB_REPORT_LAST_SIGNAL] = { 0, };
  * Private functions
  */
 static void
-gnome_db_report_destroy (GnomeDbReport *rep)
+gnome_db_report_destroy (GtkObject *object)
 {
-  g_return_if_fail(GNOME_DB_IS_REPORT(rep));
-  
-  if (rep->xmldoc != NULL) xmlFreeDoc(rep->xmldoc);
-  if (rep->file_name != NULL) g_free((gpointer) rep->file_name);
+	GnomeDbReport *rep;
+	
+	g_return_if_fail(GNOME_DB_IS_REPORT(object));
+	
+	rep = GNOME_DB_REPORT(object);
+	if (rep->xmldoc != NULL) xmlFreeDoc(rep->xmldoc);
+	if (rep->file_name != NULL) g_free((gpointer) rep->file_name);
 }
 
 /*
