@@ -11,7 +11,7 @@ int main (int argc, char *argv[])
   log_viewer = gnome_db_log_viewer_new();
   gtk_container_add(GTK_CONTAINER(window), log_viewer);
   gtk_widget_show_all(window);
-  gnome_db_log_viewer_load_file(log_viewer, "OAFIID:gda-postgres:b04e9dc2-1cc8-4027-8cf9-27dcb6a2a63f");
+  gnome_db_log_viewer_load_file(GNOME_DB_LOG_VIEWER(log_viewer), "OAFIID:gda-postgres:b04e9dc2-1cc8-4027-8cf9-27dcb6a2a63f");
   gnome_db_main(NULL);
   return 0;
 }
